<?php

namespace Controller;

use Zeedhi\Framework\DTO;
use Exception;
use Traits\TResponse;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Service\Task as TaskService;

class Task
{

    use TResponse;

    private $taskService;

    public function __construct(TaskService $taskService)
    {
        $this->taskService = $taskService;
    }

    public function findIssueClassification(DTO\Request $request, DTO\Response $response)
    {
        try {
            $data = $this->taskService->findIssueClassification();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findAutomaticFraming(DTO\Request $request, DTO\Response $response)
    {
        try {
            $param = $request->getParameters();
            $tasks_type = !empty($param['TASK_TYPE_ID']) ? $param['TASK_TYPE_ID'] : null;
            $data = $this->taskService->findAutomaticFraming($tasks_type);
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findTaskStatus(Request $request, Response $response)
    {
        try {
            $filters = '';
            $dataSet = $this->taskService->findTaskStatus($filters);
            $this->sendResponse($dataSet, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function saveAutomaticFraming(Request $request, Response $response){
        $data = $request->getParameters();
        try {
            $id = empty($data['ID']) ? null : $data['ID'];
            $time = $data['TIME'];
            $actualStatus = empty($data['TASK_STATUS_ACTUAL']) ? null : $data['TASK_STATUS_ACTUAL'];
            $destinyStatus = $data['TASK_STATUS_DESTINY'];
            $taskTypeId = $data['TASK_TYPE_ID'];
            $description = $data['DESCRIPTION'];
            $this->taskService->saveAutomaticFraming($id, $time, $actualStatus, $destinyStatus, $taskTypeId, $description);
        }
        catch(\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function removeAutomaticFraming(Request $request, Response $response){
        $datas = $request->getParameters();
        try {
            foreach ($datas["data"] as $data) {
                $id = $data['ID'];
                $this->taskService->removeAutomaticFraming($id);
            }
        }
        catch(\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
}
