<?php

namespace Repository;

use Doctrine\ORM\EntityManager;
use Doctrine\DBAL\Connection;
use Util\InstanceProvider;
use Teknisa\Model\Traits\TQuery;
use Zeedhi\DevOps\Util\Utilities;
use Zeedhi\DevOps\Model\Util\LogicalDeleted;

class BudgetItem extends RepositoryBase
{
    use TQuery;

    const ENTITY_NAME = '\Zeedhi\DevOps\Model\Projectmanagement\Entities\BudgetItem';

    /**
     * @var EntityManager
     */
    private $entityManager;

    /**
     * BudgetItem constructor.
     * @param EntityManager $entityManager
     */
    public function __construct(EntityManager $entityManager)
    {
        parent::__construct(self::ENTITY_NAME);
        $this->entityManager = $entityManager;
    }

    public function budgetItem($organizationId, $notClassificationId = null) {
        $notClassification = '';
        if($notClassificationId){
            $notClassification = <<<SQL
            AND NOT EXISTS ( SELECT  BUI.ID
                              FROM CLASSIFICATION_BUDGET_ITEM CLB
                             WHERE CLB.BUDGET_ITEM = BUI.ID
                            AND CLB.CLASSIFICATION = $notClassificationId)
SQL;
        }
        $query = <<<SQL
        SELECT * FROM (
			SELECT BUI.ID,BUI.ORGANIZATION_ID ,RES.NAME AS CREATED_BY ,BUI.CREATED_AT ,BUI.UPDATED_BY ,BUI.UPDATED_AT ,BUI.NAME ,
			       TO_CHAR(BUI.VALUE,'999G999G999G990D00', 'NLS_NUMERIC_CHARACTERS = '',.''') AS VALUE_ITEM,
			       BUI.UNIT_MEASURE,BUI.STATUS,
			       (SELECT BIB.ID FROM BUDGET_ITEM_BUDGET BIB
                            WHERE BIB.BUDGET_ITEM = BUI.ID
                              AND  ROWNUM = 1) AS NOT_DELETE
			  FROM BUDGET_ITEM BUI
			  JOIN RESOURCE_T RES ON (BUI.UPDATED_BY = RES.ID)
			 WHERE BUI.ORGANIZATION_ID = :organizationId
			   AND BUI.STATUS <> :statusDeleted
			   $notClassification
			   )
			   WHERE 1 = 1
SQL;
        $params = array(
            'organizationId' => $organizationId,
            'statusDeleted' => LogicalDeleted::STATUS_LOGICAL_DELETED,
        );

        return $this->createAndExecuteQueryAndBuildResponseData(InstanceProvider::getEntityManager(), $query, $params);
    }

    public function classificationBudgetItem($classificationId) {
        $query = <<<SQL
        SELECT * FROM (
			SELECT CLB.ID, BUI.ID AS BUDGET_ITEM_ID,BUI.ORGANIZATION_ID ,RES.NAME AS CREATED_BY ,BUI.CREATED_AT ,BUI.UPDATED_BY ,BUI.UPDATED_AT ,BUI.NAME ,
			       TO_CHAR(BUI.VALUE,'999G999G999G990D00', 'NLS_NUMERIC_CHARACTERS = '',.''') AS VALUE_ITEM,
			       BUI.UNIT_MEASURE,BUI.STATUS
			  FROM BUDGET_ITEM BUI
			  JOIN RESOURCE_T RES ON (BUI.UPDATED_BY = RES.ID)
			  JOIN CLASSIFICATION_BUDGET_ITEM CLB ON (CLB.BUDGET_ITEM = BUI.ID AND CLB.CLASSIFICATION = :classificationId)
			 WHERE BUI.STATUS <> :statusDeleted)
			   WHERE 1 = 1
SQL;
        $params = array(
            'classificationId' => $classificationId,
            'statusDeleted' => LogicalDeleted::STATUS_LOGICAL_DELETED,
        );

        return $this->createAndExecuteQueryAndBuildResponseData(InstanceProvider::getEntityManager(), $query, $params);
    }
}
