import { AlertServiceCustom } from '@/services/AlertServiceCustom';
import { DialogServiceCustom } from '@/services/DialogServiceCustom';
import { InstanceService } from '@/services/InstanceService';
import Messages from '@/services/Messages';
import { Utilities } from '@/services/Utilities';
import {
	DialogService,
	LoadingService,
	Modal,
	ModalService,
} from '@zeedhi/common';
import { Http } from '@zeedhi/core';

export class IssueBudgetItensController {
	public showIssueMainGrid = true;

	private addModal!: Modal;

	public budgetItensLabel = '';

	public showBudgetItensForm() {
		return !this.showIssueMainGrid;
	}

	public clickBackCardForm() {
		this.showIssueMainGrid = true;
	}

	public async rowClickGridBudgetItens(params: any) {
		this.budgetItensLabel = params.row.NAME;
		this.showIssueMainGrid = false;
		const formBudgetItens = InstanceService.getInstanceZdForm('formBudgetItens');
		const valueItem = parseInt(params.row.VALUE_ITEM);
		formBudgetItens.value = {
			ID: params.row.ID,
			CREATED_BY: params.row.CREATED_BY,
			CREATED_AT: params.row.CREATED_AT,
			NAME: params.row.NAME,
			VALUE_ITEM: valueItem,
			UNIT_MEASURE: params.row.UNIT_MEASURE,
			STATUS: params.row.STATUS,
		};
	}

	public async openAddBudgetItemModal() {
		if (this.addModal) {
			this.closeAddModal();
		}
		this.addModal = await ModalService.createFromJsonPost('', {
			jsonPath: 'issueConfiguration/modal/addBudgetItemModal',
		});
		this.addModal.show();
	}

	public closeAddModal() {
		this.addModal.hide();
		this.addModal?.destroy();
	}

	public saveAddModal() {
		Utilities.genericAddModalTekGrid(
			'addBudgetItemForm',
			this.addModal,
			'/budgetItems/save',
			'gridIssueBudgetItens',
			true,
		);
	}

	public async beforeDeleteGridIssueBudgetItens(params: any) {
		params.event.preventDefault();
		const buttonYes = [
			{
				name: Utilities.getNameDynamic('yes-'),
				component: 'ZdButton',
				label: 'Sim',
				events: {
					click: () => {
						DialogService.hide();
						this.doDeleteGridCommentType(params);
					},
				},
			},
		];
		DialogServiceCustom.confirmMessage(Messages.DELETE_DEFAULT, buttonYes);
	}

	public async doDeleteGridCommentType(params: any) {
		LoadingService.show();
		try {
			await Http.post('/budgetItems/remove', {
				data: params.component.selectedRows,
			});
			params.component.selectedRows = [];
			params.component.datasource.get();
		} catch (e) {
			DialogServiceCustom.showErrorBackend(e);
		}
		LoadingService.hide();
	}

	public async saveBudgetItem() {
		const formBudgetItens = InstanceService.getInstanceZdForm('formBudgetItens');
		if (formBudgetItens.validate()) {
			const valueItem = formBudgetItens.value.VALUE_ITEM;
			console.log(valueItem);
			const gridIssueBudgetItens = InstanceService.getInstanceTekGrid(
				'gridIssueBudgetItens',
			);
			LoadingService.show();
			try {
				await Http.post('/budgetItems/save', {
					ID: formBudgetItens.value.ID,
					NAME: formBudgetItens.value.NAME,
					VALUE_ITEM: formBudgetItens.value.VALUE_ITEM,
					UNIT_MEASURE: formBudgetItens.value.UNIT_MEASURE,
					STATUS: formBudgetItens.value.STATUS,
				});
				AlertServiceCustom.defaultSaveSuccessAlert();
				await gridIssueBudgetItens.datasource.get();
			} catch (e) {
				LoadingService.hide();
				DialogServiceCustom.showErrorBackend(e);
				throw e;
			}
			LoadingService.hide();
		} else {
			DialogServiceCustom.messageErrorValidate();
		}
	}
}
